@@ -125,7 +125,10 @@ def run_shell_command(cmd, cwd=None, shell=False, us_env = True, show_stdout = F
         message = None
         if p.returncode != 0 and output[1] is not None and output[1] != '':
             logger = logging.getLogger('vcstools')
-            message = "Command failed: '%s'\n errcode: %s :\n%s"%(cmd, p.returncode, output[1])
+            message = "Command failed: '%s'"%(cmd)
+            if cwd is not None:
+                message += "\n run at: '%s'"%(cwd)
+            message += "\n errcode: %s:\n%s"%(p.returncode, output[1])
             logger.warn(message)
         result = output[0]
         if result is not None:
@@ -185,7 +188,7 @@ class VcsClientBase:
         :param spec: token for identifying repository revision
         :type spec: str
         :returns: current revision number of the repository.  Or if
-        spec is provided, the respective revision number.
+          spec is provided, the respective revision number.
         :rtype: str
         """
         raise NotImplementedError, "Base class get_version method must be overridden"
@@ -211,10 +214,11 @@ class VcsClientBase:
         the spec. Fails when there are uncommited changes.
         On failures (also e.g. network failure) grants the
         checked out files are in the same state as before the call.
+
         :param spec: token for identifying repository revision
-        desired.  Token might be a tagname, branchname, version-id, 
-        SHA-ID, ... depending on the VCS implementation.
-        :return True on success, False else
+           desired.  Token might be a tagname, branchname, version-id, 
+           SHA-ID, ... depending on the VCS implementation.
+        :returns: True on success, False else
         """
         raise NotImplementedError("Base class update method must be overridden")
 
